==> haskell-yesod-test-1.6.12-199-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-test
version:              1.6.12
visibility:           public
id:                   yesod-test-1.6.12-GhLuDUN8Uhl3DoC4c8Uhlt
key:                  yesod-test-1.6.12-GhLuDUN8Uhl3DoC4c8Uhlt
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  9ced8d2661c9fb2c354423c8a8de269f
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.0.1/site-local/yesod-test-1.6.12
library-dirs:         /usr/lib/ghc-9.0.1/site-local/yesod-test-1.6.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/yesod-test-1.6.12
hs-libraries:         HSyesod-test-1.6.12-GhLuDUN8Uhl3DoC4c8Uhlt
depends:
    HUnit-1.6.2.0-2lDDmQCEetY9OrwZ2lDZMS
    aeson-1.5.6.0-Hu48mgwBrEQKjw91bueUbm
    attoparsec-0.14.1-EcyJzfZhZzx4rFmzSXlwR7 base-4.15.0.0
    blaze-builder-0.4.2.2-Iw4q9HoGXXULmCBD2udQGP
    blaze-html-0.9.1.2-8ceFSiLqnhkJTO408BmxXr bytestring-0.10.12.1
    case-insensitive-1.2.1.0-4qVPCTeB5R0AXrKebzsUFI
    conduit-1.3.4.2-CpnfzB5xaoUDvaJR7w9kCQ containers-0.6.4.1
    cookie-0.4.5-KsNYn2KTPEnIdTHNDYXGny
    hspec-core-2.8.3-FlHsbwqurj28M35FzGQLAB
    html-conduit-1.3.2.2-DU7WDSKyxs28fijxAkZtxA
    http-types-0.12.3-Jw2zWV16E9KCVTOWYhAS3k
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr mtl-2.2.2
    network-3.1.2.2-6tZsGK4OV907qcZzBxrezj
    pretty-show-1.10-G4SfLXvOfw8HasEUHDrqxD text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 wai-3.2.3-L3wgyssiaHBG0Azbs3MIRI
    wai-extra-3.1.7-8sDrZJyr32dBPu4aQydOC4
    xml-conduit-1.9.1.1-7YEXfl3eOK736efAspLm1k
    xml-types-0.3.8-144bFK4Wa4uGyLKj6w2QbB
    yesod-core-1.6.21.0-Du6krcr0amQ562jCBVKdhb

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-test-1.6.12-202-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-test
version:              1.6.12
visibility:           public
id:                   yesod-test-1.6.12-EXC3ECONhoaBkl7jIl2cTf
key:                  yesod-test-1.6.12-EXC3ECONhoaBkl7jIl2cTf
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  003cdd32b1e92c18aaa8b560f3ba100d
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.0.1/site-local/yesod-test-1.6.12
library-dirs:         /usr/lib/ghc-9.0.1/site-local/yesod-test-1.6.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/yesod-test-1.6.12
hs-libraries:         HSyesod-test-1.6.12-EXC3ECONhoaBkl7jIl2cTf
depends:
    HUnit-1.6.2.0-2lDDmQCEetY9OrwZ2lDZMS
    aeson-1.5.6.0-5xJqgJM7Xo44Ry8m4HB8YT
    attoparsec-0.14.1-2Lwpa9GUrZtgMvbVSsTwE base-4.15.0.0
    blaze-builder-0.4.2.2-Iw4q9HoGXXULmCBD2udQGP
    blaze-html-0.9.1.2-AxxHbAOepGB9XmfRN7G4vH bytestring-0.10.12.1
    case-insensitive-1.2.1.0-EnesCw45hPx54B4a098LlB
    conduit-1.3.4.2-9FsgxSw4kwI2wGCNe2ZzHA containers-0.6.4.1
    cookie-0.4.5-KsNYn2KTPEnIdTHNDYXGny
    hspec-core-2.8.3-BUYim6ecuo98I9e9xj96GB
    html-conduit-1.3.2.2-EHo8miJAAfTHA7k3wkmGaL
    http-types-0.12.3-K0EvPai3v4U1cJAtVTaqMv
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr mtl-2.2.2
    network-3.1.2.2-HakkElN3M7T6UpqfxM2fcC
    pretty-show-1.10-G4SfLXvOfw8HasEUHDrqxD text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 wai-3.2.3-LHictZmPT8k8ryz7Uzs3Yg
    wai-extra-3.1.7-6B1IXIdibvPFuyLu1rbKxC
    xml-conduit-1.9.1.1-5BbZGq10qCtBfemesGgvL
    xml-types-0.3.8-144bFK4Wa4uGyLKj6w2QbB
    yesod-core-1.6.21.0-CCO8gmheEJHCeJkmLcc1y4

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
